pub struct PgEventStore<E, S>{ /* private fields */ }Expand description
PostgreSQL event store implementation.
Implementations
Sourceimpl<E, S> PgEventStore<E, S>
impl<E, S> PgEventStore<E, S>
Sourcepub async fn try_new(pool: PgPool, serde: S) -> Result<Self, Error>
pub async fn try_new(pool: PgPool, serde: S) -> Result<Self, Error>
Initializes the PostgreSQL DB and returns a new instance of PgEventStore.
Arguments
pool- The PostgreSQL connection pool.serde- The serialization implementation for the event payload.
Sourcepub fn new_uninitialized(pool: PgPool, serde: S) -> Self
pub fn new_uninitialized(pool: PgPool, serde: S) -> Self
Creates a new instance of PgEventStore.
This constructor does not initialize the database or add the
domain_id columns necessary for disintegrate to function properly.
If you need to initialize the database, use PgEventStore::new instead.
If you plan to use this constructor, ensure that the disintegrate is
properly initialized. Refer to the SQL files in the “event_store/sql” directory
to recreate the default structure. Additionally, all domain_id columns
and their corresponding indexes must be created manually.
Arguments
pool- The PostgreSQL connection pool.serde- The serialization implementation for the event payload.